<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              http://www.maxizone.fr
 * @since             1.0.0
 * @package           Rcp_Allow_Rest
 *
 * @wordpress-plugin
 * Plugin Name:       RCP Allow REST
 * Plugin URI:        http://www.termel.fr
 * Description:       Allow RCP restricted posts to be delivered nevertheless when called from REST API
 * Version:           1.1
 * Author:            Termel
 * Author URI:        http://www.maxizone.fr
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       rcp-allow-rest
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-rcp-allow-rest-activator.php
 */
function activate_rcp_allow_rest() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-rcp-allow-rest-activator.php';
	Rcp_Allow_Rest_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-rcp-allow-rest-deactivator.php
 */
function deactivate_rcp_allow_rest() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-rcp-allow-rest-deactivator.php';
	Rcp_Allow_Rest_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_rcp_allow_rest' );
register_deactivation_hook( __FILE__, 'deactivate_rcp_allow_rest' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-rcp-allow-rest.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_rcp_allow_rest() {

	$plugin = new Rcp_Allow_Rest();
	$plugin->run();

}
run_rcp_allow_rest();
